componenttools.get_nth_component_in_time_order_from_component
=============================================================

.. autofunction:: abjad.tools.componenttools.get_nth_component_in_time_order_from_component.get_nth_component_in_time_order_from_component
   :noindex:
